##  Permissions
The table below shows which actions are available to admins and non-admin users:
User Role | Permitted Actions
---|---
Admin |
  * Export transformations from the admin area
  * Export transformations from the transformation explorer
  * Import transformations


Non-admin |
  * Export transformations from the transformation explorer




